==> library1.4.1.tar.bz2: library/book_lang/index.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['menu-btn35-title'];
$button = $TEXT['btn_filter'];
$action = "index.php";

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_GET['k'])>8) {puterror($result2['skin'],$TEXT['error-paging1']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_POST['booklang'])>255) {puterror($result2['skin'],$TEXT['error-booklang1']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_GET['booklang'])>255) {puterror($result2['skin'],$TEXT['error-booklang1']); require_once "../utils/bottom_adm.php"; exit();}
if(!empty($_GET['booklang'])) {$_POST['booklang']= $_GET['booklang'];}

$_GET['k'] = rep($_GET['k']);
$_POST['booklang'] = rep($_POST['booklang']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post >
<table align="center" border="0" cellpadding="0" cellspacing="0" width="50%">
<tr align="right">
<td width="10%" align="left"><input size=20 maxlength=255 type=text name=cicle title='<?php echo $TEXT['tbl-cicle']; ?>'></td>
<td align="left"><input class="button2" type=submit value='<?php echo $button; ?>' /></td>
<td align="right"><img alt="<?php echo $TEXT['add-new']; ?>" src="../skins/<?php echo $result2['skin']; ?>/add.png"><a class="bold_it" href="addform.php" title="<?php echo $TEXT['add-new-tit']; ?>"><?php echo $TEXT['add-new']; ?></a></td>
</tr>
</table>
<table align="center" class="table" border="1" cellpadding="3" cellspacing="0" width="50%">
<?php
if(!empty($_POST['booklang']))
 {
 $booklang = " AND LOWER(booklang) LIKE LOWER('%".$_POST['booklang']."%')";
 $stranica = $TEXT['tbl-details2'].$stop_r.$TEXT['tbl-details3'].$ktblvis;
 $bl_pered = "&amp;booklang=".$_POST['booklang'];
 }
    else
    {
     $booklang = "";
     $stranica =$TEXT['tbl-details2'].$stop_r.$TEXT['tbl-details3'].$ktblvis;
     $bl_pered = "";
    }
     $query10 = "SELECT * FROM `tbl_booklang` WHERE use_prog='1' $booklang ORDER BY position LIMIT $lim_ogr";
     $result10 = mysqli_query($dbcnx,$query10);
     if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl23']); require_once "../utils/bottom_adm.php"; exit();}
       $result_rows = mysqli_num_rows($result10);
       if($result_rows > 0)
         {
           echo " <thead>
              <tr class='tableheadercat'>
                 <td>".$TEXT['global-alt']."</td>
                 <td>".$TEXT['menu-btn35']."</td>
                 <td>".$TEXT['book-lang-pos']."</td>
                 <td colspan=3>".$TEXT['tbl-action']."</td>
              </tr>
             </thead><tbody id='tab'>";
             while($result_bl = mysqli_fetch_array($result10))
               {
              $edit_pic = "<img alt='".$TEXT['edit-new']."' src='../skins/".$result2['skin']."/edit.png' />";
              $edit = $edit_pic."&nbsp;<a href=editform.php?bl_id=".$result_bl['bl_id']." title='".$TEXT['edit-tit']."'>".$TEXT['edit-new']."</a>";

              $query_book_bl = mysqli_query($dbcnx,"SELECT COUNT(bl_id) AS co_bl_id FROM tbl_book WHERE bl_id='".$result_bl['bl_id']."'");
	       $coun_book_bl = mysqli_fetch_array($query_book_bl);
               if($coun_book_bl['co_bl_id'] > 0)
               {
               $delete_pic = "<img alt='".$TEXT['global-lock']."' src='../skins/".$result2['skin']."/nodelete.png' />";
               $delete =$delete_pic."&nbsp;".$TEXT['delete-new'];
               }
               else
               {
               $delete_pic = "<img alt='".$TEXT['delete-new']."' src='../skins/".$result2['skin']."/delete.png' />";
               $delete = $delete_pic."&nbsp;<a href=delete.php?bl_id=".$result_bl['bl_id']." title='".$TEXT['delete-tit']."'>".$TEXT['delete-new']."</a>";
               }
               if(!empty($result_bl['picture']) && is_file($result_bl['picture'])) {$pic = "<img alt='".$result_bl['booklang']."' src='../photo/".$result_bl['picture']."' />";}
                else {$pic = "---";}

               $move_up = "<a href=up-down.php?bl_id=".$result_bl['bl_id']."&amp;position=".$result_bl['position']."&amp;moving=up title='".$TEXT['global-up-down-tit']."'><img src='../skins/".$result2['skin']."/up.png' height='16' width='16' align='top' /></a>";
               $move_down = "<a href=up-down.php?bl_id=".$result_bl['bl_id']."&amp;position=".$result_bl['position']."&amp;moving=down title='".$TEXT['global-up-down-tit']."'><img src='../skins/".$result2['skin']."/down.png' height='16' width='16' align='top' /></a>";
           ?>
           <tr>
              <td><?php echo $pic; ?></td>
              <td><?php echo $result_bl['booklang']; ?></td>
              <td><?php echo $result_bl['position']; ?></td>
              <td><?php echo $move_up; ?> <?php echo $move_down; ?></td>
              <td><?php echo $edit; ?></td>
              <td><?php echo $delete; ?></td>
            </tr>
           <?php
               }
               echo "</tbody>";
         }
?>
<tfoot>
 <tr class='tableheadercat'>
 <td colspan=6 align="right"><?php echo $stranica; ?> | <?php echo $TEXT['size-count2']; ?> = <?php echo $result_rows; ?></td>
 </tr>
</tfoot>
</table>
     <?php
      $query_count = mysqli_query($dbcnx,"SELECT COUNT(bl_id) AS c_bl_id FROM tbl_booklang WHERE use_prog='1' $booklang");
	       $coun_rows = mysqli_fetch_array($query_count);
               $pag = $coun_rows['c_bl_id']/10;
               if($pag<=1) {$pag = ceil($pag);}
                else
                {
                ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='index.php?k=".$k.$bl_pered."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='index.php?k=".$k.$bl_pered."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=index.php?k=".$k.$bl_pered.">".$j."</option>";}
                       else {echo "<option value=index.php?k=".$k.$bl_pered.">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>

                 <?php
                }
?>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/book_lang/index.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['menu-btn35-title'];
$button = $TEXT['btn_filter'];
$action = "index.php";

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_GET['k'])>8) {puterror($result2['skin'],$TEXT['error-paging1']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_POST['booklang'])>255) {puterror($result2['skin'],$TEXT['error-booklang1']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_GET['booklang'])>255) {puterror($result2['skin'],$TEXT['error-booklang1']); require_once "../utils/bottom_adm.php"; exit();}
if(!empty($_GET['booklang'])) {$_POST['booklang']= $_GET['booklang'];}

$_GET['k'] = rep($_GET['k']);
$_POST['booklang'] = rep($_POST['booklang']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;
?>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post" >
<table align="center" border="0" cellpadding="0" cellspacing="0" width="50%">
<tr align="right">
<td width="10%" align="left"><input size="20" maxlength="255" type="text" name="cicle" title="<?php echo $TEXT['tbl-cicle']; ?>"></td>
<td align="left"><input class="button2" type="submit" value="<?php echo $button; ?>" /></td>
<td align="right"><img alt="<?php echo $TEXT['add-new']; ?>" src="../skins/<?php echo $result2['skin']; ?>/add.png"><a class="bold_it" href="addform.php" title="<?php echo $TEXT['add-new-tit']; ?>"><?php echo $TEXT['add-new']; ?></a></td>
</tr>
</table>
<table align="center" class="table" border="1" cellpadding="3" cellspacing="0" width="50%">
<?php
if(!empty($_POST['booklang']))
 {
 $booklang = " AND LOWER(booklang) LIKE LOWER('%".$_POST['booklang']."%')";
 $stranica = $TEXT['tbl-details2'].$stop_r.$TEXT['tbl-details3'].$ktblvis;
 $bl_pered = "&amp;booklang=".$_POST['booklang'];
 }
    else
    {
     $booklang = "";
     $stranica =$TEXT['tbl-details2'].$stop_r.$TEXT['tbl-details3'].$ktblvis;
     $bl_pered = "";
    }
     $query10 = "SELECT * FROM `tbl_booklang` WHERE use_prog='1' $booklang ORDER BY position LIMIT $lim_ogr";
     $result10 = mysqli_query($dbcnx,$query10);
     if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl23']); require_once "../utils/bottom_adm.php"; exit();}
       $result_rows = mysqli_num_rows($result10);
       if($result_rows > 0)
         {
           echo " <thead>
              <tr class='tableheadercat'>
                 <td>".$TEXT['global-alt']."</td>
                 <td>".$TEXT['menu-btn35']."</td>
                 <td>".$TEXT['book-lang-pos']."</td>
                 <td colspan=3>".$TEXT['tbl-action']."</td>
              </tr>
             </thead><tbody id='tab'>";
             while($result_bl = mysqli_fetch_array($result10))
               {
              $edit_pic = "<img alt='".$TEXT['edit-new']."' src='../skins/".$result2['skin']."/edit.png' />";
              $edit = $edit_pic."&nbsp;<a href='editform.php?bl_id=".$result_bl['bl_id']."' title='".$TEXT['edit-tit']."'>".$TEXT['edit-new']."</a>";

              $query_book_bl = mysqli_query($dbcnx,"SELECT COUNT(bl_id) AS co_bl_id FROM tbl_book WHERE bl_id='".$result_bl['bl_id']."'");
	       $coun_book_bl = mysqli_fetch_array($query_book_bl);
               if($coun_book_bl['co_bl_id'] > 0)
               {
               $delete_pic = "<img alt='".$TEXT['global-lock']."' src='../skins/".$result2['skin']."/nodelete.png' />";
               $delete =$delete_pic."&nbsp;".$TEXT['delete-new'];
               }
               else
               {
               $delete_pic = "<img alt='".$TEXT['delete-new']."' src='../skins/".$result2['skin']."/delete.png' />";
               $delete = $delete_pic."&nbsp;<a href='delete.php?bl_id=".$result_bl['bl_id']."' title='".$TEXT['delete-tit']."'>".$TEXT['delete-new']."</a>";
               }
               if(!empty($result_bl['picture']) && is_file($result_bl['picture'])) {$pic = "<img alt='".$result_bl['booklang']."' src='../photo/".$result_bl['picture']."' />";}
                else {$pic = "---";}

               $move_up = "<a href='up-down.php?bl_id=".$result_bl['bl_id']."&amp;position=".$result_bl['position']."&amp;moving=up' title='".$TEXT['global-up-down-tit']."'><img src='../skins/".$result2['skin']."/up.png' height='16' width='16' align='top' /></a>";
               $move_down = "<a href='up-down.php?bl_id=".$result_bl['bl_id']."&amp;position=".$result_bl['position']."&amp;moving=down' title='".$TEXT['global-up-down-tit']."'><img src='../skins/".$result2['skin']."/down.png' height='16' width='16' align='top' /></a>";
           ?>
           <tr>
              <td><?php echo $pic; ?></td>
              <td><?php echo $result_bl['booklang']; ?></td>
              <td><?php echo $result_bl['position']; ?></td>
              <td><?php echo $move_up; ?> <?php echo $move_down; ?></td>
              <td><?php echo $edit; ?></td>
              <td><?php echo $delete; ?></td>
            </tr>
           <?php
               }
               echo "</tbody>";
         }
?>
<tfoot>
 <tr class='tableheadercat'>
 <td colspan=6 align="right"><?php echo $stranica; ?> | <?php echo $TEXT['size-count2']; ?> = <?php echo $result_rows; ?></td>
 </tr>
</tfoot>
</table>
     <?php
      $query_count = mysqli_query($dbcnx,"SELECT COUNT(bl_id) AS c_bl_id FROM tbl_booklang WHERE use_prog='1' $booklang");
	       $coun_rows = mysqli_fetch_array($query_count);
               $pag = $coun_rows['c_bl_id']/10;
               if($pag<=1) {$pag = ceil($pag);}
                else
                {
                ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='index.php?k=".$k.$bl_pered."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='index.php?k=".$k.$bl_pered."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=index.php?k=".$k.$bl_pered.">".$j."</option>";}
                       else {echo "<option value=index.php?k=".$k.$bl_pered.">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>

                 <?php
                }
?>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>
